@@ -395,25 +395,28 @@ g_mime_content_type_get_params (GMimeContentType *mime_type)
 /**
  * g_mime_content_type_set_parameter:
  * @mime_type: MIME Content-Type
- * @attribute: parameter name (aka attribute)
+ * @name: parameter name (aka attribute)
  * @value: parameter value
  *
  * Sets a parameter on the Content-Type.
+ *
+ * Note: The @name should be in US-ASCII while the @value should be in
+ * UTF-8.
  **/
 void
-g_mime_content_type_set_parameter (GMimeContentType *mime_type, const char *attribute, const char *value)
+g_mime_content_type_set_parameter (GMimeContentType *mime_type, const char *name, const char *value)
 {
 	GMimeParam *param = NULL;
 	
 	g_return_if_fail (GMIME_IS_CONTENT_TYPE (mime_type));
-	g_return_if_fail (attribute != NULL);
+	g_return_if_fail (name != NULL);
 	g_return_if_fail (value != NULL);
 	
-	if ((param = g_hash_table_lookup (mime_type->param_hash, attribute))) {
+	if ((param = g_hash_table_lookup (mime_type->param_hash, name))) {
 		g_free (param->value);
 		param->value = g_strdup (value);
 	} else {
-		param = g_mime_param_new (attribute, value);
+		param = g_mime_param_new (name, value);
 		mime_type->params = g_mime_param_append_param (mime_type->params, param);
 		g_hash_table_insert (mime_type->param_hash, param->name, param);
 	}
@@ -425,22 +428,23 @@ g_mime_content_type_set_parameter (GMimeContentType *mime_type, const char *attr
 /**
  * g_mime_content_type_get_parameter:
  * @mime_type: a #GMimeContentType object
- * @attribute: parameter name (aka attribute)
+ * @name: parameter name (aka attribute)
  *
- * Gets the parameter value specified by @attribute if it's available.
+ * Gets the parameter value specified by @name if it's available.
  *
- * Returns: a const pointer to the paramer value specified by
- * @attribute or %NULL on fail.
+ * Returns: the value of the requested parameter or %NULL if the
+ * parameter is not set. If the parameter is set, the returned string
+ * will be in UTF-8.
  **/
 const char *
-g_mime_content_type_get_parameter (GMimeContentType *mime_type, const char *attribute)
+g_mime_content_type_get_parameter (GMimeContentType *mime_type, const char *name)
 {
 	GMimeParam *param;
 	
 	g_return_val_if_fail (GMIME_IS_CONTENT_TYPE (mime_type), NULL);
-	g_return_val_if_fail (attribute != NULL, NULL);
+	g_return_val_if_fail (name != NULL, NULL);
 	
-	if (!(param = g_hash_table_lookup (mime_type->param_hash, attribute)))
+	if (!(param = g_hash_table_lookup (mime_type->param_hash, name)))
 		return NULL;
 	
 	return param->value;
