@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2012 Jeffrey Stedfast
+ *  Copyright (C) 2000-2013 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -55,7 +55,7 @@ typedef struct _GMimeMessageClass GMimeMessageClass;
 typedef enum _GMimeRecipientType {
 	GMIME_RECIPIENT_TYPE_TO,
 	GMIME_RECIPIENT_TYPE_CC,
-	GMIME_RECIPIENT_TYPE_BCC,
+	GMIME_RECIPIENT_TYPE_BCC
 } GMimeRecipientType;
 
 
